# Posloupnosti

## Zadání

| typ                     | příklad                                                |
| ----------------------- | ------------------------------------------------------ |
| explicitní              | $a_n = 2n$                                             |
| implicitní (rekurentní) | $\begin{cases} a_{n+1} = a_n + 2\\ a_1 = 1\end{cases}$ |

## Omezenost

Posloupnost $(a_n)$ s oborem hodnot $H$ je omezená (zdola, shora), je-li množina $H$ omezená (zdola, shora).

| značení | typ                     | příklad   |
| ------- | ----------------------- | --------- |
| **O**       | omezená (shora i zdola) | $(-1)^n$  |
| **OS**      | omezená shora           | $4-n$     |
| **OZ**      | omezená zdola           | $(n-8)^2$ | 

### Minimum, maximum, infimum a supremum

Minimem (max, inf, sup) posloupnosti $(a_n)$ s oborem hodnot $H$ je minimem (max, inf, sup) množiny $H$

## Monotonie

Řekněme, že $(a_n)$ je

| značka | typ             | podmínka                                                      |
| ------ | --------------- | ------------------------------------------------------------- |
| **R**  | rostoucí        | $\displaystyle \forall n \in \mathbb{N} \ \ \ a_{n+1} >= a_n$ |
| **K**  | klesající       | $\displaystyle \forall n \in \mathbb{N} \ \ \ a_{n+1} <= a_n$ |
| **OR** | ostře rostoucí  | $\displaystyle \forall n \in \mathbb{N} \ \ \ a_{n+1} > a_n$  |
| **OK** | ostře klesající | $\displaystyle \forall n \in \mathbb{N} \ \ \ a_{n+1} < a_n$  |
| **M**  | monotónní       | je klesající nebo rostoucí                                    |
| **OM** | ostře monotónní | je ostře klesající nebo ostře rostoucí                        | 

#### Zjištění monotonie
1) Tipnu a ověřím
2) Otazníčková metoda

## Limita

### Vlastní limita

Posloupnost $(a_n)$ má vlastní limitu $a \in R$, pokud
	$\displaystyle \forall \epsilon \in R > 0 \ \ \ \exists n_{0} \in N \ \ \ \forall n \in N : n > n_{0} \implies |a_{n} - a| < \epsilon$

Píšeme $\displaystyle \lim_{ n \to \infty } a_{n} = a$ nebo $a_{n} \to a$

Pozn.: $a - \epsilon < a_{n} < a + \epsilon$
- Pro jakoukoli šířku pásma existuje standardní hodnota, všechna následující $n$ mají $a_n$ uvnitř $\epsilon$-pásem

### Nevlastní limita

Posloupnost $(a_n)$ má nevlastní limitu $+\infty$, pokud

$\displaystyle \forall h > 0 \ \ \ \exists n_{0} \ \ \ \forall n \in N : n > n_{0} \implies a_{n} > h$
	
$\displaystyle \forall d < 0 \ \ \ \exists n_{0} \ \ \ \forall n \in N : n > n_{0} \implies a_{n} < d$

Píšeme
	$\displaystyle \lim_{ n \to \infty } a_{n} = +\infty$ nebo $a_{n} \to +\infty$
	$\displaystyle \lim_{ n \to \infty } a_{n} = -\infty$ nebo $a_{n} \to -\infty$

### Jednoznačnost limity

Každá posloupnost má nejvýše 1 limitu

### Algebra vlastních limit

Nechť $\displaystyle \lim_{ n \to \infty } a_{n} = a$ a $\displaystyle \lim_{ n \to \infty } b_{n} = b$, pak
1) $\displaystyle \lim_{ n \to \infty } (\alpha \times a_{n} + \beta \times b_{n}) = \alpha \times a + \beta \times b$, pokud je pravá strana definována,

2) $\displaystyle \lim_{ n \to \infty } (a_{n} \times b_{n}) = a \times b$, pokud je pravá strana definována,

3) $\displaystyle \lim_{ n \to \infty } (\frac{a_{n}}{b_{n}}) = \frac{a}{b}$,  pokud $b_{n} \neq 0$ pro všechna $n \in N$ a pokud je pravá strana definována

### Eulerovo číslo

- je definováno jako $\displaystyle e := \lim_{ n \to \infty } \left( 1 + \frac{1}{n} \right)^n$ = |"NV $1^\infty$"|
- alternativní definice: $\displaystyle \sum_{n=0}^{\infty} \frac{1}{n!}$

## Konvergence a divergence

Řekněme, že $(a_n)$ je

| značka | typ                     | podmínka                         |
| ------ | ----------------------- | -------------------------------- |
| **K**  | konvergentní            | má-li vlastní / konečnou limitu  |
| **D**  | divergentní             | není-li konvergentní             |
|        | divergentní k $+\infty$ | má-li nevlastní limitu $+\infty$ |
|        | divergentní k $-\infty$ | má-li nevlastní limitu $-\infty$ |

### Omezenost a limity
1) Je-li posloupnost konvergentní (**K**), pak je i omezená (**O**)

2) Diverguje-li posloupnost k $+\infty$, pak je omezená pouze zdola (**OZ**)

3) Diverguje-li posloupnost k $-\infty$, pak je omezená pouze shora (**OS**)

Dále také
1) Je-li $(a_n)$ monotónní (**M**) a omezená (**O**), pak je i konvergentní (**K**)

2) Je-li $(a_n)$ rostoucí (**R**) a omezená (**O**), pak $\displaystyle \lim_{ n \to \infty } a_{n} = sup \ a_{n}$ a $min \ a_{n} = a_{1}$

3) Je-li $(a_n)$ klesající (**K**) a omezená (**O**), pak $\displaystyle \lim_{ n \to \infty } a_{n} = inf \ a_{n}$ a $max \ a_{n} = a_{1}$